import React from 'react';
import PropTypes from 'prop-types';
import { createStyledComponent } from '@cloudflare/style-container';

var getGroupByIndex = (index, length) => {
  if (index === length - 1) {
    return 'last';
  }

  if (index === 0) {
    return 'first';
  }

  return 'inbetween';
};

var addGroupProps = (children, spaced, space, direction, stretch) => React.Children.map(children, (child, index) => {
  if ( /*#__PURE__*/React.isValidElement(child)) {
    return /*#__PURE__*/React.cloneElement(child, {
      group: getGroupByIndex(index, React.Children.count(children)),
      spaced,
      space,
      direction,
      stretch
    });
  }

  return child;
});

var ButtonGroup = _ref => {
  var {
    className,
    children,
    spaced,
    space,
    direction = 'row',
    stretch
  } = _ref;
  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, addGroupProps(children, spaced, space, direction, stretch));
};

ButtonGroup.propTypes = {
  spaced: PropTypes.bool,
  space: PropTypes.number,
  stretch: PropTypes.bool,
  className: PropTypes.string.isRequired,
  direction: PropTypes.oneOf(['column', 'row'])
};
ButtonGroup.displayName = 'ButtonGroup';
export default createStyledComponent(_ref2 => {
  var {
    direction = 'row'
  } = _ref2;
  return {
    position: 'relative',
    display: 'inline-flex',
    width: direction === 'column' ? '100%' : 'initial',
    flexDirection: direction === 'column' ? 'column' : 'row',
    flexWrap: 'nowrap'
  };
}, ButtonGroup);